@@ -149,7 +149,7 @@ class DfConverter:
         c = []
         for col in columns:
             c += [col + "_value"]
-        dataframe = self.JsonRecordsToColumns(dataframe, columns=columns, inplace=False, drop=False)
+        dataframe = self.JsonRecordsToColumns(dataframe, columns=c, inplace=False, drop=False)
 
         if drop:
             dataframe.drop(columns=columns, inplace=True)
